
Properties
==========


.. automodule:: opendssdirect.Properties
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Properties.Description

    The description of the active property.

.. function:: opendssdirect.Properties.Name

    The name of the active property.

.. function:: opendssdirect.Properties.Value

    Read value of a property or Write value of a property

